@@ -1,14 +1,21 @@
-#!/usr/bin/env python
 # coding=utf-8
 
 
 class BinanceAPIException(Exception):
+
+    LISTENKEY_NOT_EXIST = '-1125'
+
     def __init__(self, response):
-        json_res = response.json()
+        self.status_code = 0
+        try:
+            json_res = response.json()
+        except ValueError:
+            self.message = 'Invalid JSON error message from Binance: {}'.format(response.text)
+        else:
+            self.code = json_res['code']
+            self.message = json_res['msg']
         self.status_code = response.status_code
         self.response = response
-        self.code = json_res['code']
-        self.message = json_res['msg']
         self.request = getattr(response, 'request', None)
 
     def __str__(self):  # pragma: no cover
